@@ -337,7 +337,12 @@ class Idw(IpolBase):
 
         self.p = p
         # query tree
-        self.dists, self.ix = self.tree.query(trg, k=self.nnearest, n_jobs=-1)
+        # scipy kwarg changed from version 1.6
+        if LooseVersion(scipy.__version__) < "1.6":
+            query_kwargs = dict(n_jobs=-1)
+        else:
+            query_kwargs = dict(workers=-1)
+        self.dists, self.ix = self.tree.query(trg, k=self.nnearest, **query_kwargs)
         # avoid bug, if there is only one neighbor at all
         if self.dists.ndim == 1:
             self.dists = self.dists[:, np.newaxis]
@@ -800,7 +805,7 @@ class IpolChain(IpolBase):
 # Covariance routines needed for Kriging
 # -----------------------------------------------------------------------------
 def parse_covariogram(cov_model):
-    """"""
+    """ """
     patterns = [
         re.compile(r"([\d\.]+) Nug\(([\d\.]+)\)"),  # nugget
         re.compile(r"([\d\.]+) Lin\(([\d\.]+)\)"),  # linear
@@ -996,7 +1001,7 @@ class OrdinaryKriging(IpolBase):
         remove_missing=False,
         **kwargs,
     ):
-        """"""
+        """ """
         if isinstance(src, spatial.cKDTree):
             self.tree = src
             self.src = self.tree.data
@@ -1179,7 +1184,7 @@ class ExternalDriftKriging(IpolBase):
         remove_missing=False,
         **kwargs,
     ):
-        """"""
+        """ """
         if isinstance(src, spatial.cKDTree):
             self.tree = src
             self.src = self.tree.data
